@@ -1,7 +1,7 @@
 #
 # This file is part of Test-Moose-More
 #
-# This software is Copyright (c) 2012 by Chris Weyl.
+# This software is Copyright (c) 2017, 2016, 2015, 2014, 2013, 2012 by Chris Weyl.
 #
 # This is free software, licensed under:
 #
@@ -9,8 +9,8 @@
 #
 package Test::Moose::More;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.043-29-g7f7738f
-$Test::Moose::More::VERSION = '0.044'; # TRIAL
+# git description: 0.048-9-ge770325
+$Test::Moose::More::VERSION = '0.049'; # TRIAL
 
 # ABSTRACT: More tools for testing Moose packages
 
@@ -22,36 +22,44 @@ use Sub::Exporter::Progressive -setup => {
         attribute_options_ok
         check_sugar_ok
         check_sugar_removed_ok
+        definition_context_ok
+        does_metaroles_ok
+        does_not_metaroles_ok
         does_not_ok
+        does_not_require_method_ok
         does_ok
         has_attribute_ok
+        has_method_from_anywhere_ok
         has_method_ok
+        has_no_method_from_anywhere_ok
         has_no_method_ok
+        is_anon
         is_anon_ok
+        is_class
         is_class_ok
         is_immutable_ok
+        is_not_anon
         is_not_anon_ok
         is_not_immutable_ok
+        is_not_pristine_ok
+        is_pristine_ok
+        is_role
         is_role_ok
         meta_ok
+        method_from_pkg_ok
+        method_is_accessor_ok
+        method_is_not_accessor_ok
+        method_not_from_pkg_ok
+        no_meta_ok
         requires_method_ok
+        role_wraps_after_method_ok
+        role_wraps_around_method_ok
+        role_wraps_before_method_ok
         validate_attribute
         validate_class
         validate_role
         validate_thing
         with_immutable
-
-        role_wraps_around_method_ok
-        role_wraps_before_method_ok
-        role_wraps_after_method_ok
-
-        is_anon
-        is_class
-        is_not_anon
-        is_role
-
-        does_metaroles_ok
-        does_not_metaroles_ok
     } ],
     groups => {
         default  => [ ':all' ],
@@ -62,6 +70,7 @@ use Sub::Exporter::Progressive -setup => {
 use Test::Builder;
 use Test::More;
 use Test::Moose 'with_immutable';
+use List::MoreUtils 'apply';
 use Scalar::Util 'blessed';
 use Syntax::Keyword::Junction 'any';
 use Moose::Util 'resolve_metatrait_alias', 'does_role', 'find_meta';
@@ -97,13 +106,11 @@ sub _thing_name {
 }
 
 
-sub meta_ok ($;$) {
-    my ($thing, $message) = @_;
-
-    my $thing_meta = find_meta($thing);
-    $message ||= _thing_name($thing, $thing_meta) . ' has a meta';
-
-    return $tb->ok(!!$thing_meta, $message);
+{
+    my $_yes = sub { $tb->ok(!!shift, shift . ' has a meta')           };
+    my $_no  = sub { $tb->ok( !shift, shift . ' does not have a meta') };
+    sub meta_ok    ($;$) { _method_ok_guts($_yes, $_[0], @_) }
+    sub no_meta_ok ($;$) { _method_ok_guts($_no,  $_[0], @_) }
 }
 
 
@@ -169,11 +176,20 @@ sub has_attribute_ok ($$;$) {
 }
 
 
-my $_has_test = sub { $tb->ok(!!$_[0]->has_method($_), "$_[1] has method $_")           };
-my $_no_test  = sub { $tb->ok( !$_[0]->has_method($_), "$_[1] does not have method $_") };
+{
+    my $_has_test = sub { $tb->ok(!!$_[0]->has_method($_), "$_[1] has method $_")           };
+    my $_no_test  = sub { $tb->ok( !$_[0]->has_method($_), "$_[1] does not have method $_") };
 
-sub has_no_method_ok ($@) { unshift @_, $_no_test;  goto \&_method_ok_guts }
-sub has_method_ok    ($@) { unshift @_, $_has_test; goto \&_method_ok_guts }
+    sub has_no_method_ok ($@) { _method_ok_guts($_no_test,  @_) }
+    sub has_method_ok    ($@) { _method_ok_guts($_has_test, @_) }
+}
+{
+    my $_has_test = sub { $tb->ok(!!$_[0]->find_method_by_name($_), "$_[1] has method $_")           };
+    my $_no_test  = sub { $tb->ok( !$_[0]->find_method_by_name($_), "$_[1] does not have method $_") };
+
+    sub has_no_method_from_anywhere_ok ($@) { _method_ok_guts($_no_test,  @_) }
+    sub has_method_from_anywhere_ok    ($@) { _method_ok_guts($_has_test, @_) }
+}
 
 sub _method_ok_guts {
     my ($_test, $thing, @methods) = @_;
@@ -182,8 +198,8 @@ sub _method_ok_guts {
     my $meta = find_meta($thing);
     my $name = _thing_name($thing, $meta);
 
-    # the test below is run one stack frame up (down?), so let's handle that
-    local $Test::Builder::Level = $Test::Builder::Level + 1;
+    # the test below is run two stack frame up (down?), so let's handle that
+    local $Test::Builder::Level = $Test::Builder::Level + 2;
 
     # "tiny evil?" -- Eleanor Weyl
 
@@ -195,9 +211,58 @@ sub _method_ok_guts {
 }
 
 
-sub role_wraps_around_method_ok ($@) { unshift @_, 'around'; goto \&_role_wraps }
-sub role_wraps_before_method_ok ($@) { unshift @_, 'before'; goto \&_role_wraps }
-sub role_wraps_after_method_ok  ($@) { unshift @_, 'after';  goto \&_role_wraps }
+{
+    my $_yes = sub { $tb->ok($_[0]->original_package_name eq $_[1], "$_[3] is from $_[1]")     };
+    my $_no  = sub { $tb->ok($_[0]->original_package_name ne $_[1], "$_[3] is not from $_[1]") };
+    sub method_from_pkg_ok($$$)     { _method_from_pkg_ok($_yes, @_) }
+    sub method_not_from_pkg_ok($$$) { _method_from_pkg_ok($_no,  @_) }
+
+    my $_yes_acc = sub { $tb->ok( $_[0]->isa('Class::MOP::Method::Accessor'), "$_[3] is an accessor method")     };
+    my $_no_acc  = sub { $tb->ok(!$_[0]->isa('Class::MOP::Method::Accessor'), "$_[3] is not an accessor method") };
+    sub method_is_accessor_ok($$)     { _method_from_pkg_ok($_yes_acc, @_) }
+    sub method_is_not_accessor_ok($$) { _method_from_pkg_ok($_no_acc,  @_) }
+}
+
+sub _method_from_pkg_ok {
+    my ($test, $thing, $method, $orig_pkg) = @_;
+
+    ### $thing
+    my $meta = find_meta($thing);
+    my $name = _thing_name($thing, $meta);
+
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+    my $mmeta = $meta->find_method_by_name($method)
+        or return $tb->ok(0, "$name has no method $method");
+
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+    return $test->($mmeta, $orig_pkg, $meta, "${name}'s method $method");
+}
+
+
+sub definition_context_ok ($$) {
+    my ($meta, $dc) = @_;
+
+    my $name = _thing_name($meta, $meta);
+
+    return unless $tb->ok(
+        $meta->can('definition_context'),
+        "$name can definition_context()",
+    );
+
+    my $meta_dc = $meta->definition_context;
+
+    ### $dc
+    ### $meta_dc
+
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+    return is_deeply $meta_dc => $dc,
+        "$name definition context is strictly correct";
+}
+
+
+sub role_wraps_around_method_ok ($@) { _role_wraps(around => @_) }
+sub role_wraps_before_method_ok ($@) { _role_wraps(before => @_) }
+sub role_wraps_after_method_ok  ($@) { _role_wraps(after  => @_) }
 
 sub _role_wraps {
     my ($style, $thing, @methods) = @_;
@@ -206,9 +271,10 @@ sub _role_wraps {
 
     ### $thing
     my $meta = find_meta($thing);
-    my $name = $meta->name;
+    my $name = _thing_name($thing, $meta);
 
     ### @methods
+    local $Test::Builder::Level = $Test::Builder::Level + 2;
     $tb->ok(!!$meta->$meta_method($_), "$name wraps $style method $_")
         for @methods;
 
@@ -216,18 +282,12 @@ sub _role_wraps {
 }
 
 
-sub requires_method_ok ($@) {
-    my ($thing, @methods) = @_;
+{
+    my $_is_test  = sub { $tb->ok( $_[0]->requires_method($_), "$_[1] requires method $_")         };
+    my $_not_test = sub { $tb->ok(!$_[0]->requires_method($_), "$_[1] does not require method $_") };
 
-    ### $thing
-    my $meta = find_meta($thing);
-    my $name = _thing_name($thing, $meta);
-
-    ### @methods
-    $tb->ok(!!$meta->requires_method($_), "$name requires method $_")
-        for @methods;
-
-    return;
+    sub requires_method_ok ($@)         { _method_ok_guts($_is_test,  @_) }
+    sub does_not_require_method_ok ($@) { _method_ok_guts($_not_test, @_) }
 }
 
 
@@ -252,6 +312,17 @@ sub is_not_immutable_ok ($;$) {
 }
 
 
+
+{
+    my $_is_test  = sub { $tb->ok( $_[0]->is_pristine(), "$_[1] is pristine")     };
+    my $_not_test = sub { $tb->ok(!$_[0]->is_pristine(), "$_[1] is not pristine") };
+
+    # FIXME should probably rename _method_ok_guts()...
+    sub is_pristine_ok ($)     { _method_ok_guts($_is_test,  @_, q{}) }
+    sub is_not_pristine_ok ($) { _method_ok_guts($_not_test, @_, q{}) }
+}
+
+
 # NOTE: deprecate at some point late 2015
 sub is_role  ($) { goto \&is_role_ok  }
 sub is_class ($) { goto \&is_class_ok }
@@ -364,6 +435,9 @@ sub _validate_subtest_wrapper {
     return $func->($thing => %args)
         unless $args{-subtest};
 
+    $args{-subtest} = _thing_name($thing)
+        if "$args{-subtest}" eq '1';
+
     # ...or with one.
     return $tb->subtest(delete $args{-subtest} => sub { $func->($thing => %args) });
 }
@@ -413,16 +487,17 @@ sub _validate_thing_guts {
     for my $attribute (@{Data::OptList::mkopt($args{attributes} || [])}) {
 
         my ($name, $opts) = @$attribute;
-        has_attribute_ok($thing, $name);
+        has_attribute_ok($thing, $name)
+            or next ATTRIBUTE_LOOP;
 
-        if ($opts && (my $att = find_meta($thing)->get_attribute($name))) {
+        if (!!$opts) {
 
             SKIP: {
                 skip 'Cannot examine attribute metaclass in roles', 1
                     if (find_meta($thing)->isa('Moose::Meta::Role'));
 
                 local $THING_NAME = _thing_name($thing) . "'s attribute $name";
-                _validate_attribute($att => (
+                _validate_attribute(_find_attribute($thing, $name) => (
                     -subtest => "checking $THING_NAME",
                     %$opts,
                 ));
@@ -531,7 +606,6 @@ sub _validate_role_guts {
     );
 }
 
-
 sub _validate_attribute       { _validate_subtest_wrapper(\&__validate_attribute_guts,                 @_) }
 sub validate_attribute ($$@)  { _validate_subtest_wrapper( \&_validate_attribute_guts, [shift, shift], @_) }
 
@@ -552,9 +626,9 @@ sub __validate_attribute_guts {
 
     local $Test::Builder::Level = $Test::Builder::Level + 1;
     my %thing_opts =
-        map  { $_ => delete $opts{"-$_"} }
-        map  { s/^-//; $_                }
-        grep { /^-/                      }
+        map   { $_ => delete $opts{"-$_"} }
+        apply { s/^-//                    }
+        grep  { /^-/                      }
         sort keys %opts
         ;
 
@@ -697,8 +771,6 @@ sub _class_attribute_options_ok {
     return;
 }
 
-1;
-
 !!42;
 
 __END__
@@ -715,7 +787,7 @@ Test::Moose::More - More tools for testing Moose packages
 
 =head1 VERSION
 
-This document describes version 0.044 of Test::Moose::More - released March 21, 2017 as part of Test-Moose-More.
+This document describes version 0.049 of Test::Moose::More - released July 30, 2017 as part of Test-Moose-More.
 
 =head1 SYNOPSIS
 
@@ -737,7 +809,7 @@ tests, and re-exports any tests that it has and we do not, yet.
 
 By default, this package exports all test functions.  You can be more
 selective, however, and there are a number of export groups (aside from the
-default ':all') to help you achieve those dreams!
+default C<:all>) to help you achieve those dreams!
 
 =over 4
 
@@ -751,23 +823,22 @@ L</validate_attribute>, L</validate_class>, L</validate_role>, L</validate_thing
 
 =back
 
-=head1 FUNCTIONS
-
-=head2 does_not_metaroles_ok $thing => { $mop => [ @traits ], ... };
-
-As with L</does_metaroles_ok>, but test that the metaroles are not consumed, a
-la L</does_not_ok>.
-
 =head1 TEST FUNCTIONS
 
 =head2 meta_ok $thing
 
-Tests $thing to see if it has a metaclass; $thing may be the class name or
-instance of the class you wish to check.
+Tests C<$thing> to see if it has a metaclass; C<$thing> may be the class name or
+instance of the class you wish to check.  Passes if C<$thing> has a metaclass.
+
+=head2 no_meta_ok $thing
+
+Tests C<$thing> to see if it does not have a metaclass; C<$thing> may be the class
+name or instance of the class you wish to check.  Passes if C<$thing> does not
+have a metaclass.
 
 =head2 does_ok $thing, < $role | \@roles >, [ $message ]
 
-Checks to see if $thing does the given roles.  $thing may be the class name or
+Checks to see if C<$thing> does the given roles.  C<$thing> may be the class name or
 instance of the class you wish to check.
 
 Note that the message will be taken verbatim unless it contains C<%s>
@@ -775,8 +846,8 @@ somewhere; this will be replaced with the name of the role being tested for.
 
 =head2 does_not_ok $thing, < $role | \@roles >, [ $message ]
 
-Checks to see if $thing does not do the given roles.  $thing may be the class
-name or instance of the class you wish to check.
+Checks to see if C<$thing> does not do the given roles.  C<$thing> may be the
+class name or instance of the class you wish to check.
 
 Note that the message will be taken verbatim unless it contains C<%s>
 somewhere; this will be replaced with the name of the role being tested for.
@@ -788,64 +859,121 @@ class name, instance, or role name.
 
 =head2 has_method_ok $thing, @methods
 
-Queries $thing's metaclass to see if $thing has the methods named in @methods.
+Queries C<$thing>'s metaclass to see if C<$thing> has the methods named in
+C<@methods>.
 
 Note: This does B<not> include inherited methods; see
 L<Class::MOP::Class/has_method>.
 
 =head2 has_no_method_ok $thing, @methods
 
-Queries $thing's metaclass to ensure $thing does not provide the methods named
-in @methods.
+Queries C<$thing>'s metaclass to ensure C<$thing> does not provide the methods named
+in C<@methods>.
 
 Note: This does B<not> include inherited methods; see
 L<Class::MOP::Class/has_method>.
 
+=head2 has_method_from_anywhere_ok $thing, @methods
+
+Queries C<$thing>'s metaclass to see if C<$thing> has the methods named in
+C<@methods>.
+
+Note: This B<does> include inherited methods; see
+L<Class::MOP::Class/find_method_by_name>.
+
+=head2 has_no_method_from_anywhere_ok $thing, @methods
+
+Queries C<$thing>'s metaclass to ensure C<$thing> does not provide the methods
+named in C<@methods>.
+
+Note: This B<does> include inherited methods; see
+L<Class::MOP::Class/find_method_by_name>.
+
+=head2 method_from_pkg_ok $thing, $method, $orig_pkg
+
+Given a thing (role, class, etc) and a method, test that it originally came
+from C<$orig_pkg>.
+
+=head2 method_not_from_pkg_ok $thing, $method, $orig_pkg
+
+Given a thing (role, class, etc) and a method, test that it did not come from
+C<$orig_pkg>.
+
+=head2 method_is_accessor_ok $thing, $method
+
+Given a thing (role, class, etc) and a method, test that the method is an
+accessor -- that is, it descends from L<Class::MOP::Method::Accessor>.
+
+=head2 method_is_not_accessor_ok $thing, $method
+
+Given a thing (role, class, etc) and a method, test that the method is B<not>
+an accessor -- that is, it does not descend from L<Class::MOP::Method::Accessor>.
+
+=head2 definition_context_ok $meta, \%dc
+
+Validates the definition context of a metaclass instance.  This is a strict
+comparison.
+
 =head2 role_wraps_around_method_ok $role, @methods
 
-Queries $role's metaclass to see if $role wraps the methods named in
-@methods with an around method modifier.
+Queries C<$role>'s metaclass to see if C<$role> wraps the methods named in
+C<@methods> with an around method modifier.
 
 =head2 role_wraps_before_method_ok $role, @methods
 
-Queries $role's metaclass to see if $role wraps the methods named in
-@methods with an before method modifier.
+Queries C<$role>'s metaclass to see if C<$role> wraps the methods named in
+C<@methods> with an before method modifier.
 
 =head2 role_wraps_after_method_ok $role, @methods
 
-Queries $role's metaclass to see if $role wraps the methods named in
-@methods with an after method modifier.
+Queries C<$role>'s metaclass to see if C<$role> wraps the methods named in
+C<@methods> with an after method modifier.
 
 =head2 requires_method_ok $thing, @methods
 
-Queries $thing's metaclass to see if $thing requires the methods named in
-@methods.
+Queries C<$thing>'s metaclass to see if C<$thing> requires the methods named in
+C<@methods>.
 
-Note that this really only makes sense if $thing is a role.
+Note that this really only makes sense if C<$thing> is a role.
+
+=head2 does_not_require_method_ok $thing, @methods
+
+Queries C<$thing>'s metaclass to ensure C<$thing> does not require the methods named
+in C<@methods>.
+
+Note that this really only makes sense if C<$thing> is a role.
 
 =head2 is_immutable_ok $thing
 
-Passes if $thing is immutable.
+Passes if C<$thing> is immutable.
 
 =head2 is_not_immutable_ok $thing
 
-Passes if $thing is not immutable; that is, is mutable.
+Passes if C<$thing> is not immutable; that is, is mutable.
+
+=head2 is_pristine_ok $thing
+
+Passes if C<$thing> is pristine.  See L<Class::MOP::Class/is_pristine>.
+
+=head2 is_not_pristine_ok $thing
+
+Passes if C<$thing> is not pristine.  See L<Class::MOP::Class/is_pristine>.
 
 =head2 is_role_ok $thing
 
-Passes if $thing's metaclass is a L<Moose::Meta::Role>.
+Passes if C<C<$thing>'s> metaclass is a L<Moose::Meta::Role>.
 
 =head2 is_class_ok $thing
 
-Passes if $thing's metaclass is a L<Moose::Meta::Class>.
+Passes if C<C<$thing>'s> metaclass is a L<Moose::Meta::Class>.
 
 =head2 is_anon_ok $thing
 
-Passes if $thing is "anonymous".
+Passes if C<$thing> is "anonymous".
 
 =head2 is_not_anon_ok $thing
 
-Passes if $thing is not "anonymous".
+Passes if C<$thing> is not "anonymous".
 
 =head2 check_sugar_removed_ok $thing
 
@@ -872,7 +1000,7 @@ L<MooseX::AttributeShortcuts> is actually applied, I could do this:
     };
     done_testing;
 
-This function will accept either class or role metaclasses for $thing.
+This function will accept either class or role metaclasses for C<$thing>.
 
 The MOPs available for classes (L<Moose::Meta::Class>) are:
 
@@ -920,12 +1048,89 @@ The MOPs available for roles (L<Moose::Meta::Role>) are:
 
 =back
 
-Note!  Neither this function nor does_not_metaroles_ok() attempts to validate
-that the MOP type passed in is a member of the above lists.  There's no gain
-here in implementing such a check, and a negative to be had: specifying an
-invalid MOP type will result in immediate explosions, while it's entirely
-possible other MOP types will be added (either to core, via traits, or "let's
-subclass Moose::Meta::Class/etc and implement something new").
+Note!  Neither this function nor C<does_not_metaroles_ok()> attempts to
+validate that the MOP type passed in is a member of the above lists.  There's
+no gain here in implementing such a check, and a negative to be had:
+specifying an invalid MOP type will result in immediate explosions, while it's
+entirely possible other MOP types will be added (either to core, via traits,
+or "let's subclass Moose::Meta::Class/etc and implement something new").
+
+=head2 does_not_metaroles_ok $thing => { $mop => [ @traits ], ... };
+
+As with L</does_metaroles_ok>, but test that the metaroles are not consumed, a
+la L</does_not_ok>.
+
+=head2 attribute_options_ok
+
+Validates that an attribute is set up as expected; like
+C<validate_attribute()>, but only concerns itself with attribute options.
+
+Note that some of these options will skip if used against attributes defined
+in a role.
+
+=over 4
+
+=item *
+
+C<< -subtest => 'subtest name...' >>
+
+If set, all tests run (save the first, "does this thing even have this
+attribute?" test) will be wrapped in a subtest, the name of which will be
+whatever C<-subtest> is set to.
+
+=item *
+
+C<< is => ro|rw >>
+
+Tests for reader/writer options set as one would expect.
+
+=item *
+
+C<< isa => ... >>
+
+Validates that the attribute requires its value to be a given type.
+
+=item *
+
+C<< does => ... >>
+
+Validates that the attribute requires its value to do a given role.
+
+=item *
+
+C<< builder => '...' >>
+
+Validates that the attribute expects the method name given to be its builder.
+
+=item *
+
+C<< default => ... >>
+
+Validates that the attribute has the given default.
+
+=item *
+
+C<< init_arg => '...' >>
+
+Validates that the attribute has the given initial argument name.
+
+=item *
+
+C<< lazy => 0|1 >>
+
+Validates that the attribute is/isn't lazy.
+
+=item *
+
+C<< required => 0|1 >>
+
+Validates that setting the attribute's value is/isn't required.
+
+=back
+
+=for Pod::Coverage is_anon is_class is_not_anon is_role
+
+=head1 VALIDATION METHODS
 
 =head2 validate_thing
 
@@ -954,42 +1159,42 @@ metaclass.
 
 =item *
 
--subtest => 'subtest name...'
+C<< -subtest => 'subtest name...' >>
 
 If set, all tests run will be wrapped in a subtest, the name of which will be
 whatever C<-subtest> is set to.
 
 =item *
 
-isa => [ ... ]
+C<< isa => [ ... ] >>
 
 A list of superclasses thing should have.
 
 =item *
 
-anonymous => 0|1
+C<< anonymous => 0|1 >>
 
 Check to see if the class is/isn't anonymous.
 
 =item *
 
-does => [ ... ]
+C<< does => [ ... ] >>
 
 A list of roles the thing should do.
 
 =item *
 
-does_not => [ ... ]
+C<< does_not => [ ... ] >>
 
 A list of roles the thing should not do.
 
 =item *
 
-attributes => [ ... ]
+C<< attributes => [ ... ] >>
 
-The attributes list specified here is in the form of a list of names, each optionally
-followed by a hashref of options to test the attribute for; this hashref takes the
-same arguments L</validate_attribute> does.  e.g.:
+The attributes list specified here is in the form of a list of names, each
+optionally followed by a hashref of options to test the attribute for; this
+hashref takes the same arguments L</validate_attribute> does.  e.g.:
 
     validate_thing $thing => (
 
@@ -1003,30 +1208,30 @@ same arguments L</validate_attribute> does.  e.g.:
 
 =item *
 
-methods => [ ... ]
+C<< methods => [ ... ] >>
 
 A list of methods the thing should have; see L</has_method_ok>.
 
 =item *
 
-no_methods => [ ... ]
+C<< no_methods => [ ... ] >>
 
 A list of methods the thing should not have; see L</has_no_method_ok>.
 
 =item *
 
-sugar => 0|1
+C<< sugar => 0|1 >>
 
 Ensure that thing can/cannot do the standard Moose sugar.
 
 =item *
 
-metaclasses => { $mop => { ... }, ... }
+C<< metaclasses => { $mop => { ... }, ... } >>
 
 Validates this thing's metaclasses: that is, given a MOP type (e.g. class,
 attribute, method, ...) and a hashref, find the associated metaclass of the
 given type and invoke L</validate_thing> on it, using the hashref as options
-for validate_thing().
+for C<validate_thing()>.
 
 e.g.
 
@@ -1049,15 +1254,15 @@ e.g.
         1..4
     ok 1 - Checking the attribute metaclass, Moose::Meta::Class::__ANON__::SERIAL::1
 
-Note that validate_class() and validate_role() implement this using
-'class_metaclasses' and 'role_metaclasses', respectively.
+Note that C<validate_class()> and C<validate_role()> implement this using
+C<class_metaclasses> and C<role_metaclasses>, respectively.
 
 =back
 
 =head2 validate_role
 
-The same as validate_thing(), but ensures C<$thing> is a role, and allows for
-additional role-specific tests.
+The same as C<validate_thing()>, but ensures C<$thing> is a role, and allows
+for additional role-specific tests.
 
     validate_role $thing => (
 
@@ -1070,10 +1275,10 @@ additional role-specific tests.
 
 =item *
 
--compose => 0|1
+C<< -compose => 0|1 >>
 
 When true, attempt to compose the role into an anonymous class, then use it to
-run L</validate_class>.  The options we're given are passed to validate_class()
+run L</validate_class>.  The options we're given are passed to C<validate_class()>
 directly, except that any C<required_methods> entry is removed and its contents
 pushed onto C<methods>.  (A stub method for each entry in C<required_methods>
 will also be created in the new class.)
@@ -1101,20 +1306,20 @@ e.g.:
 
 =item *
 
--subtest => 'subtest name...'
+C<< -subtest => 'subtest name...' >>
 
 If set, all tests run will be wrapped in a subtest, the name of which will be
 whatever C<-subtest> is set to.
 
 =item *
 
-required_methods => [ ... ]
+C<< required_methods => [ ... ] >>
 
 A list of methods the role requires a consuming class to supply.
 
 =item *
 
-before => [ ... ]
+C<< before => [ ... ] >>
 
 A list of methods the role expects to wrap before, on application to a class.
 
@@ -1122,7 +1327,7 @@ See L<Moose/before> for information on before method modifiers.
 
 =item *
 
-around => [ ... ]
+C<< around => [ ... ] >>
 
 A list of methods the role expects to wrap around, on application to a class.
 
@@ -1130,7 +1335,7 @@ See L<Moose/around> for information on around method modifiers.
 
 =item *
 
-after => [ ... ]
+C<< after => [ ... ] >>
 
 A list of methods the role expects to wrap after, on application to a class.
 
@@ -1138,26 +1343,26 @@ See L<Moose/after> for information on after method modifiers.
 
 =item *
 
-role_metaroles => { $mop => [ $role, ... ], ... }
+C<< role_metaroles => { $mop => [ $role, ... ], ... } >>
 
 Checks metaclasses to ensure the given metaroles are applied.  See
 L</does_metaroles_ok>.
 
 =item *
 
-no_role_metaroles => { $mop => [ $role, ... ], ... }
+C<< no_role_metaroles => { $mop => [ $role, ... ], ... } >>
 
 Checks metaclasses to ensure the given metaroles are applied.  See
 L</does_not_metaroles_ok>.
 
 =item *
 
-role_metaclasses => { $mop => { ... }, ... }
+C<< role_metaclasses => { $mop => { ... }, ... } >>
 
 Validates this role's metaclasses: that is, given a MOP type (e.g. role,
 attribute, method, ...) and a hashref, find the associated metaclass of the
 given type and invoke L</validate_thing> on it, using the hashref as options
-for validate_thing().
+for C<validate_thing()>.
 
 e.g.
 
@@ -1180,22 +1385,22 @@ e.g.
         1..4
     ok 1 - Checking the attribute metaclass, Moose::Meta::Class::__ANON__::SERIAL::1
 
-Note that validate_class() and validate_role() implement this using
-'class_metaclasses' and 'role_metaclasses', respectively.
+Note that C<validate_class()> and C<validate_role()> implement this using
+C<class_metaclasses> and C<role_metaclasses>, respectively.
 
 =item *
 
-class_metaclasses => { $mop => { ... }, ... }
+C<< class_metaclasses => { $mop => { ... }, ... } >>
 
 As with role_metaclasses, above, except that this option is only used
-if -compose is also specified.
+if C<-compose> is also specified.
 
 =back
 
 =head2 validate_class
 
-The same as validate_thing(), but ensures C<$thing> is a class, and allows for
-additional class-specific tests.
+The same as C<validate_thing()>, but ensures C<$thing> is a class, and allows
+for additional class-specific tests.
 
     validate_class $thing => (
 
@@ -1220,39 +1425,39 @@ additional class-specific tests.
 
 =item *
 
--subtest => 'subtest name...'
+C<< -subtest => 'subtest name...' >>
 
 If set, all tests run will be wrapped in a subtest, the name of which will be
 whatever C<-subtest> is set to.
 
 =item *
 
-immutable => 0|1
+C<< immutable => 0|1 >>
 
 Checks the class to see if it is/isn't immutable.
 
 =item *
 
-class_metaroles => { $mop => [ $role, ... ], ... }
+C<< class_metaroles => { $mop => [ $role, ... ], ... } >>
 
 Checks metaclasses to ensure the given metaroles are applied.  See
 L</does_metaroles_ok>.
 
 =item *
 
-no_class_metaroles => { $mop => [ $role, ... ], ... }
+C<< no_class_metaroles => { $mop => [ $role, ... ], ... } >>
 
 Checks metaclasses to ensure the given metaroles are applied.  See
 L</does_not_metaroles_ok>.
 
 =item *
 
-class_metaclasses => { $mop => { ... }, ... }
+C<< class_metaclasses => { $mop => { ... }, ... } >>
 
 Validates this class' metaclasses: that is, given a MOP type (e.g. role,
 attribute, method, ...) and a hashref, find the associated metaclass of the
 given type and invoke L</validate_thing> on it, using the hashref as options
-for validate_thing().
+for C<validate_thing()>.
 
 e.g.
 
@@ -1281,8 +1486,8 @@ e.g.
 
 =head2 validate_attribute
 
-validate_attribute() allows you to test how an attribute looks once built and
-attached to a class.
+C<validate_attribute()> allows you to test how an attribute looks once built
+and attached to a class.
 
 Let's say you have an attribute defined like this:
 
@@ -1294,8 +1499,8 @@ Let's say you have an attribute defined like this:
         lazy    => 1,
     );
 
-You can use validate_attribute() to ensure that it's built out in the way you
-expect:
+You can use C<validate_attribute()> to ensure that it's built out in the way
+you expect:
 
     validate_attribute TestClass => foo => (
 
@@ -1316,10 +1521,11 @@ expect:
         required => undef,
     );
 
-Options passed to validate_attribute() prefixed with '-' test the attribute's metaclass
-instance rather than a setting on the attribute; that is, '-does' ensures that the
-metaclass does a particular role (e.g. L<MooseX::AttributeShortcuts>), while 'does' tests
-the setting of the attribute to require the value do a given role.
+Options passed to C<validate_attribute()> prefixed with C<-> test the
+attribute's metaclass instance rather than a setting on the attribute; that
+is, C<-does> ensures that the metaclass does a particular role (e.g.
+L<MooseX::AttributeShortcuts>), while C<does> tests the setting of the
+attribute to require the value do a given role.
 
 This function takes all the options L</attribute_options_ok> takes, as well as
 the following:
@@ -1328,82 +1534,13 @@ the following:
 
 =item *
 
--subtest => 'subtest name...'
+C<< -subtest => 'subtest name...' >>
 
 If set, all tests run will be wrapped in a subtest, the name of which will be
 whatever C<-subtest> is set to.
 
 =back
 
-=head2 attribute_options_ok
-
-Validates that an attribute is set up as expected; like validate_attribute(),
-but only concerns itself with attribute options.
-
-Note that some of these options will skip if used against attributes defined in a role.
-
-=over 4
-
-=item *
-
--subtest => 'subtest name...'
-
-If set, all tests run (save the first, "does this thing even have this
-attribute?" test) will be wrapped in a subtest, the name of which will be
-whatever C<-subtest> is set to.
-
-=item *
-
-is => ro|rw
-
-Tests for reader/writer options set as one would expect.
-
-=item *
-
-isa => ...
-
-Validates that the attribute requires its value to be a given type.
-
-=item *
-
-does => ...
-
-Validates that the attribute requires its value to do a given role.
-
-=item *
-
-builder => '...'
-
-Validates that the attribute expects the method name given to be its builder.
-
-=item *
-
-default => ...
-
-Validates that the attribute has the given default.
-
-=item *
-
-init_arg => '...'
-
-Validates that the attribute has the given initial argument name.
-
-=item *
-
-lazy => 0|1
-
-Validates that the attribute is/isn't lazy.
-
-=item *
-
-required => 0|1
-
-Validates that setting the attribute's value is/isn't required.
-
-=back
-
-=for Pod::Coverage is_anon is_class is_not_anon is_role
-
 =head1 SEE ALSO
 
 Please see those modules/websites for more information related to this module.
@@ -1447,7 +1584,7 @@ Karen Etheridge <ether@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Chris Weyl.
+This software is Copyright (c) 2017, 2016, 2015, 2014, 2013, 2012 by Chris Weyl.
 
 This is free software, licensed under:
 
